@@ -22,7 +22,7 @@ class InteligerManager(models.Manager):
         ini = time.time()
         qs = InteligerQuerySet(self.model)
         fim = time.time()
-        tempo = Inteliger.tempo_pesquisa
+        tempo = Inteliger().tempo_pesquisa
         if 0 < tempo < fim - ini:
             Query = apps.get_model('log', 'Query')
             Query(
